@@ -1,3 +1,11 @@
+from traitlets.config.configurable import Configurable
+from tornado import gen
+from traitlets import Unicode
+
+CredentialConfig = namedtuple('CredentialConfig', [
+    'access_key_id', 'secret_access_key'
+])
+
 class CortxAuthenticator(Configurable):
     access_key_id = Unicode(config=True)
     secret_access_key = Unicode(config=True)
